==> openwhisk-runtime-nodejs-1.19.0-sources.tar.gz: openwhisk-runtime-nodejs-1.19.0/core/nodejs14Action/CHANGELOG.md <==
<!--
#
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
-->

# NodeJS 14 OpenWhisk Runtime Container

# Apache 1.19
  - Remove Node.js 10 support
  - Update Node to 14.17.2 and 12.22.2 (#197)
  - Resolve akka versions explicitly. (#198)

Node.js version = [14.17.2](https://nodejs.org/en/blog/release/v14.17.2/)
OpenWhisk version = [OpenWhisk v3.21.4](https://www.npmjs.com/package/openwhisk)

# Apache 1.18
  - Update to openwhisk-client-js 3.21.4 (#194)
  - Constraint all transitive akka-* dependencies (#195)
  - Update NodeJs to gather fixes (#192)
  - Update NodeJs to gather fixes (#188)
  - Update from source build. (#187)
  - Update NodeJs to gather fixes (#186)

Node.js version = [14.16.1](https://nodejs.org/en/blog/release/v14.16.1/)
OpenWhisk version = [OpenWhisk v3.21.4](https://www.npmjs.com/package/openwhisk)

## Apache 1.17
  - Update Node.js and OpenWhisk versions.

Node.js version = [14.15.1](https://nodejs.org/en/blog/release/v14.15.1/)
OpenWhisk version = [OpenWhisk v3.21.3](https://www.npmjs.com/package/openwhisk)

## Apache 1.16
Changes:
  - Initial release with support for Node.js v1.14

Node.js version = [14.4.0](https://nodejs.org/en/blog/release/v14.4.0/)
OpenWhisk version = [OpenWhisk v3.21.2](https://www.npmjs.com/package/openwhisk)

==> openwhisk-runtime-nodejs-1.20.0-sources.tar.gz: openwhisk-runtime-nodejs-1.20.0/core/nodejs14Action/CHANGELOG.md <==
<!--
#
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
-->

# NodeJS 14 OpenWhisk Runtime Container

# Apache 1.20
- Update Node to 14.19.x
Node.js version = [14.19.1](https://nodejs.org/en/blog/release/v14.19.1/)
OpenWhisk version = [OpenWhisk v3.21.6](https://www.npmjs.com/package/openwhisk)

# Apache 1.19
  - Remove Node.js 10 support
  - Update Node to 14.17.2 and 12.22.2 (#197)
  - Resolve akka versions explicitly. (#198)

Node.js version = [14.17.2](https://nodejs.org/en/blog/release/v14.17.2/)
OpenWhisk version = [OpenWhisk v3.21.4](https://www.npmjs.com/package/openwhisk)

# Apache 1.18
  - Update to openwhisk-client-js 3.21.4 (#194)
  - Constraint all transitive akka-* dependencies (#195)
  - Update NodeJs to gather fixes (#192)
  - Update NodeJs to gather fixes (#188)
  - Update from source build. (#187)
  - Update NodeJs to gather fixes (#186)

Node.js version = [14.16.1](https://nodejs.org/en/blog/release/v14.16.1/)
OpenWhisk version = [OpenWhisk v3.21.4](https://www.npmjs.com/package/openwhisk)

## Apache 1.17
  - Update Node.js and OpenWhisk versions.

Node.js version = [14.15.1](https://nodejs.org/en/blog/release/v14.15.1/)
OpenWhisk version = [OpenWhisk v3.21.3](https://www.npmjs.com/package/openwhisk)

## Apache 1.16
Changes:
  - Initial release with support for Node.js v1.14

Node.js version = [14.4.0](https://nodejs.org/en/blog/release/v14.4.0/)
OpenWhisk version = [OpenWhisk v3.21.2](https://www.npmjs.com/package/openwhisk)
